@@ -287,7 +287,8 @@ def general_obj_delete(request, name, general_obj_id):
 
 def general_objs(request, Obj, ObjForm, fields=(), query_dict={}, query_term='', \
         excluded_query_dict={}, no_id_in_fields=False, \
-        show_unused_download_excelsheet_button=False, *args, **kwargs):
+        show_unused_download_excelsheet_button=False, \
+        translations_field_names={}, *args, **kwargs):
     """General view for displaying records of an object
     
     It' s not a real view, rather a generic function to displaying filtered list of an Object with a datatable.
@@ -344,6 +345,7 @@ def general_objs(request, Obj, ObjForm, fields=(), query_dict={}, query_term='',
                 else:
                     field.append(render_to_string(field_htmls[field_name], {ret_dic['obj_name'].lower(): obj}))
         fields.append(field)
+    field_names = [translations_field_names[fn] if fn in translations_field_names else fn for fn in field_names]
     ret_dic['field_names'] = field_names
     ret_dic['fields'] = fields
     ret_dic['objs'] = Obj.objects.filter()
